@@ -405,9 +405,10 @@ module Contracts
 
       def valid?(arg)
         return false unless arg.is_a?(Hash)
+        return false unless arg.keys.sort.eql?(contract_hash.keys.sort)
 
-        contract_hash.all? do |key, _v|
-          contract_hash.key?(key) && Contract.valid?(arg[key], contract_hash[key])
+        contract_hash.all? do |key, contract|
+          contract_hash.key?(key) && Contract.valid?(arg[key], contract)
         end
       end
     end
@@ -441,7 +442,7 @@ module Contracts
     end
 
     # Use this for specifying contracts for class arguments
-    # Example: <tt>Descendant[ e: Range, f: Optional[Num] ]</tt>
+    # Example: <tt>DescendantOf[ e: Range, f: Optional[Num] ]</tt>
     class DescendantOf < CallableClass
       def initialize(parent_class)
         @parent_class = parent_class
